# aio_dtls

[![img lib ver](https://img.shields.io/pypi/v/aio_dtls.svg "")](https://pypi.python.org/pypi/aio_dtls)
[![img python ver](https://img.shields.io/pypi/pyversions/aio_dtls.svg "")](https://pypi.python.org/pypi/aio_dtls)
[![img license](https://img.shields.io/pypi/l/aio_dtls.svg "")](https://pypi.python.org/pypi/aio_dtls)

The implementation of dtls was made to connect to the iotivity which uses the mbedtls and not the standard cipher.

Handshake dtls and tls for ECDHE_ANON is working now

A simple example of use can be seen in example.py

An example implementation of the COAPS protocol in Bubot_CoAP


